@@ -42,7 +42,9 @@ TimelineView::TimelineView(void)
 
     view2 = new QGraphicsView;
 
-//    _gpsLocation = new Maemo5GPS;
+    #ifdef LIBLOCATION
+        _gpsLocation = new Maemo5GPS;
+    #endif // LIBLOCATION
 }
 
 /*!
@@ -63,8 +65,10 @@ TimelineView::~TimelineView()
     if(view2)
         delete view2;
 
-//    if(this->_gpsLocation)
-//        delete this->_gpsLocation;
+    #ifdef LIBLOCATION
+        if(this->_gpsLocation)
+            delete this->_gpsLocation;
+    #endif // LIBLOCATION
 }
 
 /*!
@@ -233,7 +237,7 @@ void TimelineView::_createButtons()
 
     _exposeButton = new TwitterButton(TwitterButton::Expose, NULL, this);
     _exposeButton->setOpacity(0);
-    _exposeButton->setZValue(2.0);
+    _exposeButton->setZValue(3.0);
 
     _logoutButton = new TwitterButton(TwitterButton::Logout, "Logout", this);
     _logoutButton->setOpacity(0);
@@ -600,7 +604,9 @@ void TimelineView::getIPCoordinates()
 {
     qDebug() << "+ " << __PRETTY_FUNCTION__;
 
-    QMaemo5InformationBox::information(NULL, tr("Acquiring geographical information through your IP"), QMaemo5InformationBox::DefaultTimeout);
+    #ifdef LIBLOCATION
+        QMaemo5InformationBox::information(NULL, tr("Acquiring geographical information through your IP"), QMaemo5InformationBox::DefaultTimeout);
+    #endif // LIBLOCATION
 
     _ipLocation->getLocation();
 }
@@ -612,8 +618,10 @@ void TimelineView::_showIpLocationInfo(double latitude, double longitude)
 {
     qDebug() << "+ " << __PRETTY_FUNCTION__;
 
-    QMaemo5InformationBox::information(NULL, tr("GOT IT! Latitude = %1, Longitude = %2").arg(latitude).arg(longitude),
+    #ifdef LIBLOCATION
+        QMaemo5InformationBox::information(NULL, tr("GOT IT! Latitude = %1, Longitude = %2").arg(latitude).arg(longitude),
                                            QMaemo5InformationBox::DefaultTimeout);
+    #endif // LIBLOCATION
 }
 
 /*!
@@ -630,11 +638,13 @@ void TimelineView::_emitChangeAvatar(QString image)
  */
 void TimelineView::getGPSCoordinates()
 {
-//    qDebug() << "+ " << __PRETTY_FUNCTION__;
-//
-//    _gpsLocation->get_agnss();
-//    QMaemo5InformationBox::information(NULL, tr("Acquiring GPS information"), QMaemo5InformationBox::DefaultTimeout);
-//    connect(_gpsLocation, SIGNAL(getOK_agnss()), this, SIGNAL(gotGPS()));
+    qDebug() << "+ " << __PRETTY_FUNCTION__;
+
+    #ifdef LIBLOCATION
+        _gpsLocation->get_agnss();
+        QMaemo5InformationBox::information(NULL, tr("Acquiring GPS information"), QMaemo5InformationBox::DefaultTimeout);
+        connect(_gpsLocation, SIGNAL(getOK_agnss()), this, SIGNAL(gotGPS()));
+    #endif // LIBLOCATION
 }
 
 /*!
@@ -932,7 +942,7 @@ void TimelineView::_openTwitPic()
 {
     m_twitPic = new TwitPic(this);
     connect(m_twitPic, SIGNAL(animExit()), this, SLOT(_closeTwitPic()));
-    m_twitPic->setZValue(1.0);
+    m_twitPic->setZValue(2.5);
     m_twitPic->download(_tweetInfo->getTwitPicUrl() + "/full");
 
     QPropertyAnimation *animate = new QPropertyAnimation(m_twitPic, "scale");
